@@ -1,7 +1,7 @@
 /* poppler-private.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2008, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2006-2009, 2011, 2012, 2017-2020 by Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2006-2009, 2011, 2012, 2017-2021 by Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2007-2009, 2011, 2014 by Pino Toscano <pino@kde.org>
  * Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
  * Copyright (C) 2011 Hib Eris <hib@hiberis.nl>
@@ -65,7 +65,6 @@
 
 class LinkDest;
 class FormWidget;
-class OutlineItem;
 
 namespace Poppler {
 
@@ -197,7 +196,7 @@ public:
         type = FontInfo::unknown;
     }
 
-    FontInfoData(::FontInfo *fi)
+    explicit FontInfoData(::FontInfo *fi)
     {
         if (fi->getName())
             fontName = fi->getName()->c_str();
